roots

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2021 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FindRoots

func FindRoots(f common.System, D common.Derivative, b_low mat.Vector, b_up mat.Vector,
	params *Params) []mat.Vector

FindRoots tries to find all roots of f in given multi-dim-interval. The algorithm uses a heuristic search (PSO) which imposes no restrictions on f. A recursive bisection procedure ensures the pso-search to provide as much as possible independent results. In case the system is n*n and a derivative is supplied, it is used for a Newton-method to refine roots. If the system is n*n and no derivative is supplied, the derivative will be approximated internally.

func RefineRoots

func RefineRoots(f common.System, D common.Derivative, roots []mat.Vector, params *Params) []mat.Vector

Types

type Params

type Params = struct {
	Root_Recognition   float64 // f(x) to be recognized as root by particles
	Location_Precision float64 // min distance to distinguish several roots
	N_particles        int     // based on the dimension and size of interval, one must play with this
	Precision          float64 // aimed precission of root
}

type Segment

type Segment = struct {
	// contains filtered or unexported fields
}

Jump to